"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PrivateCloudConnection(google.protobuf.message.Message):
    """A Private cloud connection resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PrivateCloudConnection._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: PrivateCloudConnection._Status.ValueType  # 0
        """Unspecified private cloud connection status."""
        CREATING: PrivateCloudConnection._Status.ValueType  # 1
        """Private cloud connection is waiting for network resources to be allocated."""
        READY: PrivateCloudConnection._Status.ValueType  # 2
        """Private cloud connection is ready to use."""
        ERROR: PrivateCloudConnection._Status.ValueType  # 3
        """Private cloud connection encountered a problem and cannot operate."""
        DELETING: PrivateCloudConnection._Status.ValueType  # 4
        """Private cloud connection is being deleted."""
        UPDATING: PrivateCloudConnection._Status.ValueType  # 5
        """Private cloud connection is being updated."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Private cloud connection status."""

    STATUS_UNSPECIFIED: PrivateCloudConnection.Status.ValueType  # 0
    """Unspecified private cloud connection status."""
    CREATING: PrivateCloudConnection.Status.ValueType  # 1
    """Private cloud connection is waiting for network resources to be allocated."""
    READY: PrivateCloudConnection.Status.ValueType  # 2
    """Private cloud connection is ready to use."""
    ERROR: PrivateCloudConnection.Status.ValueType  # 3
    """Private cloud connection encountered a problem and cannot operate."""
    DELETING: PrivateCloudConnection.Status.ValueType  # 4
    """Private cloud connection is being deleted."""
    UPDATING: PrivateCloudConnection.Status.ValueType  # 5
    """Private cloud connection is being updated."""

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    ROUTING_INSTANCE_ID_FIELD_NUMBER: builtins.int
    VRF_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the private cloud connection."""
    folder_id: builtins.str
    """ID of the folder that the private cloud connection belongs to."""
    cloud_id: builtins.str
    """ID of the cloud that the private cloud connection belongs to."""
    routing_instance_id: builtins.str
    """ID of Cloud Router Routing Instance."""
    vrf_id: builtins.str
    """ID of VRF that is connected to routing Instance."""
    status: global___PrivateCloudConnection.Status.ValueType
    """Status of the private cloud connection."""
    name: builtins.str
    """Name of the private cloud connection."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        cloud_id: builtins.str = ...,
        routing_instance_id: builtins.str = ...,
        vrf_id: builtins.str = ...,
        status: global___PrivateCloudConnection.Status.ValueType = ...,
        name: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "created_at", b"created_at", "folder_id", b"folder_id", "id", b"id", "name", b"name", "routing_instance_id", b"routing_instance_id", "status", b"status", "vrf_id", b"vrf_id"]) -> None: ...

global___PrivateCloudConnection = PrivateCloudConnection



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/baremetal/v1alpha/hardware_pool_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/baremetal/v1alpha/hardware_pool_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.baremetal.v1alpha import hardware_pool_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_hardware__pool__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/baremetal/v1alpha/hardware_pool_service.proto\x12\x1eyandex.cloud.baremetal.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x32yandex/cloud/baremetal/v1alpha/hardware_pool.proto\x1a\x1dyandex/cloud/validation.proto\"<\n\x16GetHardwarePoolRequest\x12\"\n\x10hardware_pool_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=20\"R\n\x18ListHardwarePoolsRequest\x12\x1c\n\tpage_size\x18\x64 \x01(\x03\x42\t\xfa\xc7\x31\x05<=100\x12\x12\n\npage_token\x18\x65 \x01(\tJ\x04\x08\x01\x10\x64\"\x80\x01\n\x19ListHardwarePoolsResponse\x12\x44\n\x0ehardware_pools\x18\x01 \x03(\x0b\x32,.yandex.cloud.baremetal.v1alpha.HardwarePool\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\x32\xe8\x02\n\x13HardwarePoolService\x12\xa8\x01\n\x03Get\x12\x36.yandex.cloud.baremetal.v1alpha.GetHardwarePoolRequest\x1a,.yandex.cloud.baremetal.v1alpha.HardwarePool\";\x82\xd3\xe4\x93\x02\x35\x12\x33/baremetal/v1alpha/hardwarePools/{hardware_pool_id}\x12\xa5\x01\n\x04List\x12\x38.yandex.cloud.baremetal.v1alpha.ListHardwarePoolsRequest\x1a\x39.yandex.cloud.baremetal.v1alpha.ListHardwarePoolsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /baremetal/v1alpha/hardwarePoolsBr\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.baremetal.v1alpha.hardware_pool_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetal'
  _globals['_GETHARDWAREPOOLREQUEST'].fields_by_name['hardware_pool_id']._loaded_options = None
  _globals['_GETHARDWAREPOOLREQUEST'].fields_by_name['hardware_pool_id']._serialized_options = b'\212\3101\004<=20'
  _globals['_LISTHARDWAREPOOLSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTHARDWAREPOOLSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\005<=100'
  _globals['_HARDWAREPOOLSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_HARDWAREPOOLSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0025\0223/baremetal/v1alpha/hardwarePools/{hardware_pool_id}'
  _globals['_HARDWAREPOOLSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_HARDWAREPOOLSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\"\022 /baremetal/v1alpha/hardwarePools'
  _globals['_GETHARDWAREPOOLREQUEST']._serialized_start=207
  _globals['_GETHARDWAREPOOLREQUEST']._serialized_end=267
  _globals['_LISTHARDWAREPOOLSREQUEST']._serialized_start=269
  _globals['_LISTHARDWAREPOOLSREQUEST']._serialized_end=351
  _globals['_LISTHARDWAREPOOLSRESPONSE']._serialized_start=354
  _globals['_LISTHARDWAREPOOLSRESPONSE']._serialized_end=482
  _globals['_HARDWAREPOOLSERVICE']._serialized_start=485
  _globals['_HARDWAREPOOLSERVICE']._serialized_end=845
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.cdn.v1.shielding_pb2
import yandex.cloud.cdn.v1.shielding_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ShieldingServiceStub:
    """Shielding management service."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Activate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.shielding_service_pb2.ActivateShieldingRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Activate shielding for a resource."""

    Deactivate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.shielding_service_pb2.DeactivateShieldingRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deactivate shielding for a resource."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.shielding_service_pb2.GetShieldingDetailsRequest,
        yandex.cloud.cdn.v1.shielding_pb2.ShieldingDetails,
    ]
    """Get shielding details by resource ID."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.shielding_service_pb2.UpdateShieldingRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates shielding parameters for a resource, such as changing the geographical location of the shielding server.
    Changes may take up to 15 minutes to propagate across CDN servers.
    After updating, it is recommended to purge the resource's cache.
    """

    ListAvailableLocations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.shielding_service_pb2.ListShieldingLocationsRequest,
        yandex.cloud.cdn.v1.shielding_service_pb2.ListShieldingLocationsResponse,
    ]
    """Lists available geographical locations."""

class ShieldingServiceAsyncStub:
    """Shielding management service."""

    Activate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.shielding_service_pb2.ActivateShieldingRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Activate shielding for a resource."""

    Deactivate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.shielding_service_pb2.DeactivateShieldingRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deactivate shielding for a resource."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.shielding_service_pb2.GetShieldingDetailsRequest,
        yandex.cloud.cdn.v1.shielding_pb2.ShieldingDetails,
    ]
    """Get shielding details by resource ID."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.shielding_service_pb2.UpdateShieldingRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates shielding parameters for a resource, such as changing the geographical location of the shielding server.
    Changes may take up to 15 minutes to propagate across CDN servers.
    After updating, it is recommended to purge the resource's cache.
    """

    ListAvailableLocations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.shielding_service_pb2.ListShieldingLocationsRequest,
        yandex.cloud.cdn.v1.shielding_service_pb2.ListShieldingLocationsResponse,
    ]
    """Lists available geographical locations."""

class ShieldingServiceServicer(metaclass=abc.ABCMeta):
    """Shielding management service."""

    @abc.abstractmethod
    def Activate(
        self,
        request: yandex.cloud.cdn.v1.shielding_service_pb2.ActivateShieldingRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Activate shielding for a resource."""

    @abc.abstractmethod
    def Deactivate(
        self,
        request: yandex.cloud.cdn.v1.shielding_service_pb2.DeactivateShieldingRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deactivate shielding for a resource."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.cdn.v1.shielding_service_pb2.GetShieldingDetailsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cdn.v1.shielding_pb2.ShieldingDetails, collections.abc.Awaitable[yandex.cloud.cdn.v1.shielding_pb2.ShieldingDetails]]:
        """Get shielding details by resource ID."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.cdn.v1.shielding_service_pb2.UpdateShieldingRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates shielding parameters for a resource, such as changing the geographical location of the shielding server.
        Changes may take up to 15 minutes to propagate across CDN servers.
        After updating, it is recommended to purge the resource's cache.
        """

    @abc.abstractmethod
    def ListAvailableLocations(
        self,
        request: yandex.cloud.cdn.v1.shielding_service_pb2.ListShieldingLocationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cdn.v1.shielding_service_pb2.ListShieldingLocationsResponse, collections.abc.Awaitable[yandex.cloud.cdn.v1.shielding_service_pb2.ListShieldingLocationsResponse]]:
        """Lists available geographical locations."""

def add_ShieldingServiceServicer_to_server(servicer: ShieldingServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.compute.v1.disk_pb2
import yandex.cloud.compute.v1.disk_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class DiskServiceStub:
    """A set of methods for managing Disk resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_service_pb2.GetDiskRequest,
        yandex.cloud.compute.v1.disk_pb2.Disk,
    ]
    """Returns the specified Disk resource.

    To get the list of available Disk resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_service_pb2.ListDisksRequest,
        yandex.cloud.compute.v1.disk_service_pb2.ListDisksResponse,
    ]
    """Retrieves the list of Disk resources in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_service_pb2.CreateDiskRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a disk in the specified folder.

    You can create an empty disk or restore it from a snapshot or an image.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_service_pb2.UpdateDiskRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified disk."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_service_pb2.DeleteDiskRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified disk.

    Deleting a disk removes its data permanently and is irreversible. However, deleting a disk does not delete
    any snapshots or images previously made from the disk. You must delete snapshots and images separately.

    It is not possible to delete a disk that is attached to an instance.
    """

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_service_pb2.ListDiskOperationsRequest,
        yandex.cloud.compute.v1.disk_service_pb2.ListDiskOperationsResponse,
    ]
    """Lists operations for the specified disk."""

    Move: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_service_pb2.MoveDiskRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Moves the specified disk to another folder of the same cloud."""

    Relocate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_service_pb2.RelocateDiskRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Moves the specified disk to another availability zone

    Disk must be detached from instances. To move attached
    disk use [InstanceService.Relocate] request.
    """

    ListSnapshotSchedules: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_service_pb2.ListDiskSnapshotSchedulesRequest,
        yandex.cloud.compute.v1.disk_service_pb2.ListDiskSnapshotSchedulesResponse,
    ]
    """Retrieves the list of snapshot schedules the specified disk is attached to."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the disk.
    """

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the disk."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the disk."""

class DiskServiceAsyncStub:
    """A set of methods for managing Disk resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_service_pb2.GetDiskRequest,
        yandex.cloud.compute.v1.disk_pb2.Disk,
    ]
    """Returns the specified Disk resource.

    To get the list of available Disk resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_service_pb2.ListDisksRequest,
        yandex.cloud.compute.v1.disk_service_pb2.ListDisksResponse,
    ]
    """Retrieves the list of Disk resources in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_service_pb2.CreateDiskRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a disk in the specified folder.

    You can create an empty disk or restore it from a snapshot or an image.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_service_pb2.UpdateDiskRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified disk."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_service_pb2.DeleteDiskRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified disk.

    Deleting a disk removes its data permanently and is irreversible. However, deleting a disk does not delete
    any snapshots or images previously made from the disk. You must delete snapshots and images separately.

    It is not possible to delete a disk that is attached to an instance.
    """

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_service_pb2.ListDiskOperationsRequest,
        yandex.cloud.compute.v1.disk_service_pb2.ListDiskOperationsResponse,
    ]
    """Lists operations for the specified disk."""

    Move: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_service_pb2.MoveDiskRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Moves the specified disk to another folder of the same cloud."""

    Relocate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_service_pb2.RelocateDiskRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Moves the specified disk to another availability zone

    Disk must be detached from instances. To move attached
    disk use [InstanceService.Relocate] request.
    """

    ListSnapshotSchedules: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_service_pb2.ListDiskSnapshotSchedulesRequest,
        yandex.cloud.compute.v1.disk_service_pb2.ListDiskSnapshotSchedulesResponse,
    ]
    """Retrieves the list of snapshot schedules the specified disk is attached to."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the disk.
    """

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the disk."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the disk."""

class DiskServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Disk resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.compute.v1.disk_service_pb2.GetDiskRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.disk_pb2.Disk, collections.abc.Awaitable[yandex.cloud.compute.v1.disk_pb2.Disk]]:
        """Returns the specified Disk resource.

        To get the list of available Disk resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.compute.v1.disk_service_pb2.ListDisksRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.disk_service_pb2.ListDisksResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.disk_service_pb2.ListDisksResponse]]:
        """Retrieves the list of Disk resources in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.compute.v1.disk_service_pb2.CreateDiskRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a disk in the specified folder.

        You can create an empty disk or restore it from a snapshot or an image.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.compute.v1.disk_service_pb2.UpdateDiskRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified disk."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.compute.v1.disk_service_pb2.DeleteDiskRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified disk.

        Deleting a disk removes its data permanently and is irreversible. However, deleting a disk does not delete
        any snapshots or images previously made from the disk. You must delete snapshots and images separately.

        It is not possible to delete a disk that is attached to an instance.
        """

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.compute.v1.disk_service_pb2.ListDiskOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.disk_service_pb2.ListDiskOperationsResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.disk_service_pb2.ListDiskOperationsResponse]]:
        """Lists operations for the specified disk."""

    @abc.abstractmethod
    def Move(
        self,
        request: yandex.cloud.compute.v1.disk_service_pb2.MoveDiskRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Moves the specified disk to another folder of the same cloud."""

    @abc.abstractmethod
    def Relocate(
        self,
        request: yandex.cloud.compute.v1.disk_service_pb2.RelocateDiskRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Moves the specified disk to another availability zone

        Disk must be detached from instances. To move attached
        disk use [InstanceService.Relocate] request.
        """

    @abc.abstractmethod
    def ListSnapshotSchedules(
        self,
        request: yandex.cloud.compute.v1.disk_service_pb2.ListDiskSnapshotSchedulesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.disk_service_pb2.ListDiskSnapshotSchedulesResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.disk_service_pb2.ListDiskSnapshotSchedulesResponse]]:
        """Retrieves the list of snapshot schedules the specified disk is attached to."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """access

        Lists access bindings for the disk.
        """

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the disk."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the disk."""

def add_DiskServiceServicer_to_server(servicer: DiskServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cloudregistry/v1/ip_permission.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cloudregistry/v1/ip_permission.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/cloudregistry/v1/ip_permission.proto\x12\x1dyandex.cloud.cloudregistry.v1\x1a\x1dyandex/cloud/validation.proto\"\x94\x01\n\x0cIpPermission\x12\x42\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x32.yandex.cloud.cloudregistry.v1.IpPermission.Action\x12\n\n\x02ip\x18\x02 \x01(\t\"4\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\x08\n\x04PULL\x10\x01\x12\x08\n\x04PUSH\x10\x02\"\xab\x01\n\x11IpPermissionDelta\x12L\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x36.yandex.cloud.cloudregistry.v1.IpPermissionDeltaActionB\x04\xe8\xc7\x31\x01\x12H\n\rip_permission\x18\x02 \x01(\x0b\x32+.yandex.cloud.cloudregistry.v1.IpPermissionB\x04\xe8\xc7\x31\x01*Z\n\x17IpPermissionDeltaAction\x12*\n&IP_PERMISSION_DELTA_ACTION_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41\x44\x44\x10\x01\x12\n\n\x06REMOVE\x10\x02\x42t\n!yandex.cloud.api.cloudregistry.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudregistry/v1;cloudregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cloudregistry.v1.ip_permission_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.cloudregistry.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudregistry/v1;cloudregistry'
  _globals['_IPPERMISSIONDELTA'].fields_by_name['action']._loaded_options = None
  _globals['_IPPERMISSIONDELTA'].fields_by_name['action']._serialized_options = b'\350\3071\001'
  _globals['_IPPERMISSIONDELTA'].fields_by_name['ip_permission']._loaded_options = None
  _globals['_IPPERMISSIONDELTA'].fields_by_name['ip_permission']._serialized_options = b'\350\3071\001'
  _globals['_IPPERMISSIONDELTAACTION']._serialized_start=440
  _globals['_IPPERMISSIONDELTAACTION']._serialized_end=530
  _globals['_IPPERMISSION']._serialized_start=116
  _globals['_IPPERMISSION']._serialized_end=264
  _globals['_IPPERMISSION_ACTION']._serialized_start=212
  _globals['_IPPERMISSION_ACTION']._serialized_end=264
  _globals['_IPPERMISSIONDELTA']._serialized_start=267
  _globals['_IPPERMISSIONDELTA']._serialized_end=438
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/lockbox/v1/payload_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/lockbox/v1/payload_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.lockbox.v1 import payload_pb2 as yandex_dot_cloud_dot_lockbox_dot_v1_dot_payload__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/lockbox/v1/payload_service.proto\x12\x17yandex.cloud.lockbox.v1\x1a\x1cgoogle/api/annotations.proto\x1a%yandex/cloud/lockbox/v1/payload.proto\x1a\x1dyandex/cloud/validation.proto\"R\n\x11GetPayloadRequest\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\nversion_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"\xa8\x01\n\x0cGetExRequest\x12\x1d\n\tsecret_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x41\n\x0f\x66older_and_name\x18\x02 \x01(\x0b\x32&.yandex.cloud.lockbox.v1.FolderAndNameH\x00\x12\x1c\n\nversion_id\x18\x15 \x01(\tB\x08\x8a\xc8\x31\x04<=50B\x12\n\nidentifier\x12\x04\xc0\xc1\x31\x01J\x04\x08\x03\x10\x15\"T\n\rFolderAndName\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\"\n\x0bsecret_name\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\"\xac\x01\n\rGetExResponse\x12\x11\n\tsecret_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\x12\x44\n\x07\x65ntries\x18\x03 \x03(\x0b\x32\x33.yandex.cloud.lockbox.v1.GetExResponse.EntriesEntry\x1a.\n\x0c\x45ntriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x32\x92\x02\n\x0ePayloadService\x12\x84\x01\n\x03Get\x12*.yandex.cloud.lockbox.v1.GetPayloadRequest\x1a .yandex.cloud.lockbox.v1.Payload\"/\x82\xd3\xe4\x93\x02)\x12\'/lockbox/v1/secrets/{secret_id}/payload\x12y\n\x05GetEx\x12%.yandex.cloud.lockbox.v1.GetExRequest\x1a&.yandex.cloud.lockbox.v1.GetExResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/lockbox/v1/secrets:getExBb\n\x1byandex.cloud.api.lockbox.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/lockbox/v1;lockboxb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.lockbox.v1.payload_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.lockbox.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/lockbox/v1;lockbox'
  _globals['_GETPAYLOADREQUEST'].fields_by_name['secret_id']._loaded_options = None
  _globals['_GETPAYLOADREQUEST'].fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETPAYLOADREQUEST'].fields_by_name['version_id']._loaded_options = None
  _globals['_GETPAYLOADREQUEST'].fields_by_name['version_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_GETEXREQUEST'].oneofs_by_name['identifier']._loaded_options = None
  _globals['_GETEXREQUEST'].oneofs_by_name['identifier']._serialized_options = b'\300\3011\001'
  _globals['_GETEXREQUEST'].fields_by_name['secret_id']._loaded_options = None
  _globals['_GETEXREQUEST'].fields_by_name['secret_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_GETEXREQUEST'].fields_by_name['version_id']._loaded_options = None
  _globals['_GETEXREQUEST'].fields_by_name['version_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_FOLDERANDNAME'].fields_by_name['folder_id']._loaded_options = None
  _globals['_FOLDERANDNAME'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_FOLDERANDNAME'].fields_by_name['secret_name']._loaded_options = None
  _globals['_FOLDERANDNAME'].fields_by_name['secret_name']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_GETEXRESPONSE_ENTRIESENTRY']._loaded_options = None
  _globals['_GETEXRESPONSE_ENTRIESENTRY']._serialized_options = b'8\001'
  _globals['_PAYLOADSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_PAYLOADSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002)\022\'/lockbox/v1/secrets/{secret_id}/payload'
  _globals['_PAYLOADSERVICE'].methods_by_name['GetEx']._loaded_options = None
  _globals['_PAYLOADSERVICE'].methods_by_name['GetEx']._serialized_options = b'\202\323\344\223\002\033\022\031/lockbox/v1/secrets:getEx'
  _globals['_GETPAYLOADREQUEST']._serialized_start=174
  _globals['_GETPAYLOADREQUEST']._serialized_end=256
  _globals['_GETEXREQUEST']._serialized_start=259
  _globals['_GETEXREQUEST']._serialized_end=427
  _globals['_FOLDERANDNAME']._serialized_start=429
  _globals['_FOLDERANDNAME']._serialized_end=513
  _globals['_GETEXRESPONSE']._serialized_start=516
  _globals['_GETEXRESPONSE']._serialized_end=688
  _globals['_GETEXRESPONSE_ENTRIESENTRY']._serialized_start=642
  _globals['_GETEXRESPONSE_ENTRIESENTRY']._serialized_end=688
  _globals['_PAYLOADSERVICE']._serialized_start=691
  _globals['_PAYLOADSERVICE']._serialized_end=965
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iot/broker/v1/broker_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iot/broker/v1/broker_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.iot.broker.v1 import broker_pb2 as yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/iot/broker/v1/broker_service.proto\x12\x1ayandex.cloud.iot.broker.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\'yandex/cloud/iot/broker/v1/broker.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"3\n\x10GetBrokerRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"s\n\x12ListBrokersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"c\n\x13ListBrokersResponse\x12\x33\n\x07\x62rokers\x18\x01 \x03(\x0b\x32\".yandex.cloud.iot.broker.v1.Broker\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x85\x04\n\x13\x43reateBrokerRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12(\n\x04name\x18\x02 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=50\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x88\x01\n\x06labels\x18\x04 \x03(\x0b\x32;.yandex.cloud.iot.broker.v1.CreateBrokerRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12Q\n\x0c\x63\x65rtificates\x18\x05 \x03(\x0b\x32;.yandex.cloud.iot.broker.v1.CreateBrokerRequest.Certificate\x12\x10\n\x08password\x18\x06 \x01(\t\x12;\n\x0blog_options\x18\x07 \x01(\x0b\x32&.yandex.cloud.iot.broker.v1.LogOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\'\n\x0b\x43\x65rtificate\x12\x18\n\x10\x63\x65rtificate_data\x18\x01 \x01(\t\")\n\x14\x43reateBrokerMetadata\x12\x11\n\tbroker_id\x18\x01 \x01(\t\"\xa8\x03\n\x13UpdateBrokerRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12(\n\x04name\x18\x03 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=50\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x88\x01\n\x06labels\x18\x05 \x03(\x0b\x32;.yandex.cloud.iot.broker.v1.UpdateBrokerRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12;\n\x0blog_options\x18\x06 \x01(\x0b\x32&.yandex.cloud.iot.broker.v1.LogOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\")\n\x14UpdateBrokerMetadata\x12\x11\n\tbroker_id\x18\x01 \x01(\t\"6\n\x13\x44\x65leteBrokerRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x14\x44\x65leteBrokerMetadata\x12\x11\n\tbroker_id\x18\x01 \x01(\t\"@\n\x1dListBrokerCertificatesRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"e\n\x1eListBrokerCertificatesResponse\x12\x43\n\x0c\x63\x65rtificates\x18\x01 \x03(\x0b\x32-.yandex.cloud.iot.broker.v1.BrokerCertificate\"^\n\x1b\x41\x64\x64\x42rokerCertificateRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x18\n\x10\x63\x65rtificate_data\x18\x03 \x01(\tJ\x04\x08\x02\x10\x03\"F\n\x1c\x41\x64\x64\x42rokerCertificateMetadata\x12\x11\n\tbroker_id\x18\x01 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x02 \x01(\t\"d\n\x1e\x44\x65leteBrokerCertificateRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x0b\x66ingerprint\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"e\n\x1f\x44\x65leteBrokerCertificateMetadata\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x0b\x66ingerprint\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"=\n\x1aListBrokerPasswordsRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\\\n\x1bListBrokerPasswordsResponse\x12=\n\tpasswords\x18\x01 \x03(\x0b\x32*.yandex.cloud.iot.broker.v1.BrokerPassword\"W\n\x18\x41\x64\x64\x42rokerPasswordRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x08password\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04>=14\"C\n\x19\x41\x64\x64\x42rokerPasswordMetadata\x12\x11\n\tbroker_id\x18\x01 \x01(\t\x12\x13\n\x0bpassword_id\x18\x02 \x01(\t\"a\n\x1b\x44\x65leteBrokerPasswordRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x0bpassword_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"b\n\x1c\x44\x65leteBrokerPasswordMetadata\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x0bpassword_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x1bListBrokerOperationsRequest\x12\x17\n\tbroker_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"n\n\x1cListBrokerOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x80\x12\n\rBrokerService\x12\x83\x01\n\x03Get\x12,.yandex.cloud.iot.broker.v1.GetBrokerRequest\x1a\".yandex.cloud.iot.broker.v1.Broker\"*\x82\xd3\xe4\x93\x02$\x12\"/iot-broker/v1/brokers/{broker_id}\x12\x87\x01\n\x04List\x12..yandex.cloud.iot.broker.v1.ListBrokersRequest\x1a/.yandex.cloud.iot.broker.v1.ListBrokersResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/iot-broker/v1/brokers\x12\xa1\x01\n\x06\x43reate\x12/.yandex.cloud.iot.broker.v1.CreateBrokerRequest\x1a!.yandex.cloud.operation.Operation\"C\xb2\xd2*\x1e\n\x14\x43reateBrokerMetadata\x12\x06\x42roker\x82\xd3\xe4\x93\x02\x1b\"\x16/iot-broker/v1/brokers:\x01*\x12\xad\x01\n\x06Update\x12/.yandex.cloud.iot.broker.v1.UpdateBrokerRequest\x1a!.yandex.cloud.operation.Operation\"O\xb2\xd2*\x1e\n\x14UpdateBrokerMetadata\x12\x06\x42roker\x82\xd3\xe4\x93\x02\'2\"/iot-broker/v1/brokers/{broker_id}:\x01*\x12\xb9\x01\n\x06\x44\x65lete\x12/.yandex.cloud.iot.broker.v1.DeleteBrokerRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2*-\n\x14\x44\x65leteBrokerMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02$*\"/iot-broker/v1/brokers/{broker_id}\x12\xc2\x01\n\x10ListCertificates\x12\x39.yandex.cloud.iot.broker.v1.ListBrokerCertificatesRequest\x1a:.yandex.cloud.iot.broker.v1.ListBrokerCertificatesResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//iot-broker/v1/brokers/{broker_id}/certificates\x12\xdd\x01\n\x0e\x41\x64\x64\x43\x65rtificate\x12\x37.yandex.cloud.iot.broker.v1.AddBrokerCertificateRequest\x1a!.yandex.cloud.operation.Operation\"o\xb2\xd2*1\n\x1c\x41\x64\x64\x42rokerCertificateMetadata\x12\x11\x42rokerCertificate\x82\xd3\xe4\x93\x02\x34\"//iot-broker/v1/brokers/{broker_id}/certificates:\x01*\x12\xf6\x01\n\x11\x44\x65leteCertificate\x12:.yandex.cloud.iot.broker.v1.DeleteBrokerCertificateRequest\x1a!.yandex.cloud.operation.Operation\"\x81\x01\xb2\xd2*8\n\x1f\x44\x65leteBrokerCertificateMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02?*=/iot-broker/v1/brokers/{broker_id}/certificates/{fingerprint}\x12\xb6\x01\n\rListPasswords\x12\x36.yandex.cloud.iot.broker.v1.ListBrokerPasswordsRequest\x1a\x37.yandex.cloud.iot.broker.v1.ListBrokerPasswordsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/iot-broker/v1/brokers/{broker_id}/passwords\x12\xce\x01\n\x0b\x41\x64\x64Password\x12\x34.yandex.cloud.iot.broker.v1.AddBrokerPasswordRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*+\n\x19\x41\x64\x64\x42rokerPasswordMetadata\x12\x0e\x42rokerPassword\x82\xd3\xe4\x93\x02\x31\",/iot-broker/v1/brokers/{broker_id}/passwords:\x01*\x12\xe9\x01\n\x0e\x44\x65letePassword\x12\x37.yandex.cloud.iot.broker.v1.DeleteBrokerPasswordRequest\x1a!.yandex.cloud.operation.Operation\"{\xb2\xd2*5\n\x1c\x44\x65leteBrokerPasswordMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02<*:/iot-broker/v1/brokers/{broker_id}/passwords/{password_id}\x12\xba\x01\n\x0eListOperations\x12\x37.yandex.cloud.iot.broker.v1.ListBrokerOperationsRequest\x1a\x38.yandex.cloud.iot.broker.v1.ListBrokerOperationsResponse\"5\x82\xd3\xe4\x93\x02/\x12-/iot-broker/v1/brokers/{broker_id}/operationsBg\n\x1eyandex.cloud.api.iot.broker.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/broker/v1;brokerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iot.broker.v1.broker_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.iot.broker.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/broker/v1;broker'
  _globals['_GETBROKERREQUEST'].fields_by_name['broker_id']._loaded_options = None
  _globals['_GETBROKERREQUEST'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTBROKERSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTBROKERSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTBROKERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTBROKERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTBROKERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTBROKERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATEBROKERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEBROKERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEBROKERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEBROKERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEBROKERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEBROKERREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=50'
  _globals['_CREATEBROKERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEBROKERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATEBROKERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEBROKERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATEBROKERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEBROKERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEBROKERREQUEST'].fields_by_name['broker_id']._loaded_options = None
  _globals['_UPDATEBROKERREQUEST'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEBROKERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEBROKERREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=50'
  _globals['_UPDATEBROKERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEBROKERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEBROKERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEBROKERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_DELETEBROKERREQUEST'].fields_by_name['broker_id']._loaded_options = None
  _globals['_DELETEBROKERREQUEST'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTBROKERCERTIFICATESREQUEST'].fields_by_name['broker_id']._loaded_options = None
  _globals['_LISTBROKERCERTIFICATESREQUEST'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDBROKERCERTIFICATEREQUEST'].fields_by_name['broker_id']._loaded_options = None
  _globals['_ADDBROKERCERTIFICATEREQUEST'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEBROKERCERTIFICATEREQUEST'].fields_by_name['broker_id']._loaded_options = None
  _globals['_DELETEBROKERCERTIFICATEREQUEST'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEBROKERCERTIFICATEREQUEST'].fields_by_name['fingerprint']._loaded_options = None
  _globals['_DELETEBROKERCERTIFICATEREQUEST'].fields_by_name['fingerprint']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEBROKERCERTIFICATEMETADATA'].fields_by_name['broker_id']._loaded_options = None
  _globals['_DELETEBROKERCERTIFICATEMETADATA'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEBROKERCERTIFICATEMETADATA'].fields_by_name['fingerprint']._loaded_options = None
  _globals['_DELETEBROKERCERTIFICATEMETADATA'].fields_by_name['fingerprint']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTBROKERPASSWORDSREQUEST'].fields_by_name['broker_id']._loaded_options = None
  _globals['_LISTBROKERPASSWORDSREQUEST'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDBROKERPASSWORDREQUEST'].fields_by_name['broker_id']._loaded_options = None
  _globals['_ADDBROKERPASSWORDREQUEST'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDBROKERPASSWORDREQUEST'].fields_by_name['password']._loaded_options = None
  _globals['_ADDBROKERPASSWORDREQUEST'].fields_by_name['password']._serialized_options = b'\212\3101\004>=14'
  _globals['_DELETEBROKERPASSWORDREQUEST'].fields_by_name['broker_id']._loaded_options = None
  _globals['_DELETEBROKERPASSWORDREQUEST'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEBROKERPASSWORDREQUEST'].fields_by_name['password_id']._loaded_options = None
  _globals['_DELETEBROKERPASSWORDREQUEST'].fields_by_name['password_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEBROKERPASSWORDMETADATA'].fields_by_name['broker_id']._loaded_options = None
  _globals['_DELETEBROKERPASSWORDMETADATA'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEBROKERPASSWORDMETADATA'].fields_by_name['password_id']._loaded_options = None
  _globals['_DELETEBROKERPASSWORDMETADATA'].fields_by_name['password_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTBROKEROPERATIONSREQUEST'].fields_by_name['broker_id']._loaded_options = None
  _globals['_LISTBROKEROPERATIONSREQUEST'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTBROKEROPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTBROKEROPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTBROKEROPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTBROKEROPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTBROKEROPERATIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTBROKEROPERATIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_BROKERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002$\022\"/iot-broker/v1/brokers/{broker_id}'
  _globals['_BROKERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\030\022\026/iot-broker/v1/brokers'
  _globals['_BROKERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\036\n\024CreateBrokerMetadata\022\006Broker\202\323\344\223\002\033\"\026/iot-broker/v1/brokers:\001*'
  _globals['_BROKERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\036\n\024UpdateBrokerMetadata\022\006Broker\202\323\344\223\002\'2\"/iot-broker/v1/brokers/{broker_id}:\001*'
  _globals['_BROKERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*-\n\024DeleteBrokerMetadata\022\025google.protobuf.Empty\202\323\344\223\002$*\"/iot-broker/v1/brokers/{broker_id}'
  _globals['_BROKERSERVICE'].methods_by_name['ListCertificates']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['ListCertificates']._serialized_options = b'\202\323\344\223\0021\022//iot-broker/v1/brokers/{broker_id}/certificates'
  _globals['_BROKERSERVICE'].methods_by_name['AddCertificate']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['AddCertificate']._serialized_options = b'\262\322*1\n\034AddBrokerCertificateMetadata\022\021BrokerCertificate\202\323\344\223\0024\"//iot-broker/v1/brokers/{broker_id}/certificates:\001*'
  _globals['_BROKERSERVICE'].methods_by_name['DeleteCertificate']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['DeleteCertificate']._serialized_options = b'\262\322*8\n\037DeleteBrokerCertificateMetadata\022\025google.protobuf.Empty\202\323\344\223\002?*=/iot-broker/v1/brokers/{broker_id}/certificates/{fingerprint}'
  _globals['_BROKERSERVICE'].methods_by_name['ListPasswords']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['ListPasswords']._serialized_options = b'\202\323\344\223\002.\022,/iot-broker/v1/brokers/{broker_id}/passwords'
  _globals['_BROKERSERVICE'].methods_by_name['AddPassword']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['AddPassword']._serialized_options = b'\262\322*+\n\031AddBrokerPasswordMetadata\022\016BrokerPassword\202\323\344\223\0021\",/iot-broker/v1/brokers/{broker_id}/passwords:\001*'
  _globals['_BROKERSERVICE'].methods_by_name['DeletePassword']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['DeletePassword']._serialized_options = b'\262\322*5\n\034DeleteBrokerPasswordMetadata\022\025google.protobuf.Empty\202\323\344\223\002<*:/iot-broker/v1/brokers/{broker_id}/passwords/{password_id}'
  _globals['_BROKERSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002/\022-/iot-broker/v1/brokers/{broker_id}/operations'
  _globals['_GETBROKERREQUEST']._serialized_start=289
  _globals['_GETBROKERREQUEST']._serialized_end=340
  _globals['_LISTBROKERSREQUEST']._serialized_start=342
  _globals['_LISTBROKERSREQUEST']._serialized_end=457
  _globals['_LISTBROKERSRESPONSE']._serialized_start=459
  _globals['_LISTBROKERSRESPONSE']._serialized_end=558
  _globals['_CREATEBROKERREQUEST']._serialized_start=561
  _globals['_CREATEBROKERREQUEST']._serialized_end=1078
  _globals['_CREATEBROKERREQUEST_LABELSENTRY']._serialized_start=992
  _globals['_CREATEBROKERREQUEST_LABELSENTRY']._serialized_end=1037
  _globals['_CREATEBROKERREQUEST_CERTIFICATE']._serialized_start=1039
  _globals['_CREATEBROKERREQUEST_CERTIFICATE']._serialized_end=1078
  _globals['_CREATEBROKERMETADATA']._serialized_start=1080
  _globals['_CREATEBROKERMETADATA']._serialized_end=1121
  _globals['_UPDATEBROKERREQUEST']._serialized_start=1124
  _globals['_UPDATEBROKERREQUEST']._serialized_end=1548
  _globals['_UPDATEBROKERREQUEST_LABELSENTRY']._serialized_start=992
  _globals['_UPDATEBROKERREQUEST_LABELSENTRY']._serialized_end=1037
  _globals['_UPDATEBROKERMETADATA']._serialized_start=1550
  _globals['_UPDATEBROKERMETADATA']._serialized_end=1591
  _globals['_DELETEBROKERREQUEST']._serialized_start=1593
  _globals['_DELETEBROKERREQUEST']._serialized_end=1647
  _globals['_DELETEBROKERMETADATA']._serialized_start=1649
  _globals['_DELETEBROKERMETADATA']._serialized_end=1690
  _globals['_LISTBROKERCERTIFICATESREQUEST']._serialized_start=1692
  _globals['_LISTBROKERCERTIFICATESREQUEST']._serialized_end=1756
  _globals['_LISTBROKERCERTIFICATESRESPONSE']._serialized_start=1758
  _globals['_LISTBROKERCERTIFICATESRESPONSE']._serialized_end=1859
  _globals['_ADDBROKERCERTIFICATEREQUEST']._serialized_start=1861
  _globals['_ADDBROKERCERTIFICATEREQUEST']._serialized_end=1955
  _globals['_ADDBROKERCERTIFICATEMETADATA']._serialized_start=1957
  _globals['_ADDBROKERCERTIFICATEMETADATA']._serialized_end=2027
  _globals['_DELETEBROKERCERTIFICATEREQUEST']._serialized_start=2029
  _globals['_DELETEBROKERCERTIFICATEREQUEST']._serialized_end=2129
  _globals['_DELETEBROKERCERTIFICATEMETADATA']._serialized_start=2131
  _globals['_DELETEBROKERCERTIFICATEMETADATA']._serialized_end=2232
  _globals['_LISTBROKERPASSWORDSREQUEST']._serialized_start=2234
  _globals['_LISTBROKERPASSWORDSREQUEST']._serialized_end=2295
  _globals['_LISTBROKERPASSWORDSRESPONSE']._serialized_start=2297
  _globals['_LISTBROKERPASSWORDSRESPONSE']._serialized_end=2389
  _globals['_ADDBROKERPASSWORDREQUEST']._serialized_start=2391
  _globals['_ADDBROKERPASSWORDREQUEST']._serialized_end=2478
  _globals['_ADDBROKERPASSWORDMETADATA']._serialized_start=2480
  _globals['_ADDBROKERPASSWORDMETADATA']._serialized_end=2547
  _globals['_DELETEBROKERPASSWORDREQUEST']._serialized_start=2549
  _globals['_DELETEBROKERPASSWORDREQUEST']._serialized_end=2646
  _globals['_DELETEBROKERPASSWORDMETADATA']._serialized_start=2648
  _globals['_DELETEBROKERPASSWORDMETADATA']._serialized_end=2746
  _globals['_LISTBROKEROPERATIONSREQUEST']._serialized_start=2749
  _globals['_LISTBROKEROPERATIONSREQUEST']._serialized_end=2893
  _globals['_LISTBROKEROPERATIONSRESPONSE']._serialized_start=2895
  _globals['_LISTBROKEROPERATIONSRESPONSE']._serialized_end=3005
  _globals['_BROKERSERVICE']._serialized_start=3008
  _globals['_BROKERSERVICE']._serialized_end=5312
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cic/v1/trunk_connection_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cic/v1/trunk_connection_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.cic.v1.common import transceiver_type_pb2 as yandex_dot_cloud_dot_cic_dot_v1_dot_common_dot_transceiver__type__pb2
from yandex.cloud.cic.v1.common import lag_allocation_settings_pb2 as yandex_dot_cloud_dot_cic_dot_v1_dot_common_dot_lag__allocation__settings__pb2
from yandex.cloud.cic.v1 import trunk_connection_pb2 as yandex_dot_cloud_dot_cic_dot_v1_dot_trunk__connection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/cic/v1/trunk_connection_service.proto\x12\x13yandex.cloud.cic.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x31yandex/cloud/cic/v1/common/transceiver_type.proto\x1a\x38yandex/cloud/cic/v1/common/lag_allocation_settings.proto\x1a*yandex/cloud/cic/v1/trunk_connection.proto\"F\n\x19GetTrunkConnectionRequest\x12)\n\x13trunk_connection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x98\x01\n\x1bListTrunkConnectionsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"x\n\x1cListTrunkConnectionsResponse\x12?\n\x11trunk_connections\x18\x01 \x03(\x0b\x32$.yandex.cloud.cic.v1.TrunkConnection\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xf0\x08\n\x1c\x43reateTrunkConnectionRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tfolder_id\x18\x04 \x01(\t\x12\x11\n\tregion_id\x18\x05 \x01(\t\x12k\n\x18single_port_direct_joint\x18\n \x01(\x0b\x32G.yandex.cloud.cic.v1.CreateTrunkConnectionRequest.SinglePortDirectJointH\x00\x12\\\n\x10lag_direct_joint\x18\x0b \x01(\x0b\x32@.yandex.cloud.cic.v1.CreateTrunkConnectionRequest.LagDirectJointH\x00\x12\\\n\x12partner_joint_info\x18\x0c \x01(\x0b\x32>.yandex.cloud.cic.v1.CreateTrunkConnectionRequest.PartnerJointH\x00\x12:\n\x14point_of_presence_id\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x08\x63\x61pacity\x18\x11 \x01(\x0e\x32-.yandex.cloud.cic.v1.TrunkConnection.Capacity\x12\x8a\x01\n\x06labels\x18\x12 \x03(\x0b\x32=.yandex.cloud.cic.v1.CreateTrunkConnectionRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x1b\n\x13\x64\x65letion_protection\x18\x14 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x64\n\x15SinglePortDirectJoint\x12\x45\n\x10transceiver_type\x18\x01 \x01(\x0e\x32+.yandex.cloud.cic.v1.common.TransceiverTypeJ\x04\x08\x02\x10\x05\x1a\xb8\x01\n\x0eLagDirectJoint\x12\x45\n\x10transceiver_type\x18\x01 \x01(\x0e\x32+.yandex.cloud.cic.v1.common.TransceiverType\x12Y\n\x17lag_allocation_settings\x18\x03 \x01(\x0b\x32\x38.yandex.cloud.cic.v1.common.LagAllocationSettingsRequestJ\x04\x08\x02\x10\x03\x1a\x46\n\x0cPartnerJoint\x12\x30\n\npartner_id\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueJ\x04\x08\x01\x10\x04\x42\x07\n\x05jointJ\x04\x08\x03\x10\x04J\x04\x08\x06\x10\nJ\x04\x08\x0e\x10\x11J\x04\x08\x13\x10\x14\"<\n\x1d\x43reateTrunkConnectionMetadata\x12\x1b\n\x13trunk_connection_id\x18\x01 \x01(\t\"\x9e\x04\n\x1cUpdateTrunkConnectionRequest\x12)\n\x13trunk_connection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x11\n\tregion_id\x18\x07 \x01(\t\x12:\n\x14point_of_presence_id\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x08\x63\x61pacity\x18\x11 \x01(\x0e\x32-.yandex.cloud.cic.v1.TrunkConnection.Capacity\x12\x8a\x01\n\x06labels\x18\x12 \x03(\x0b\x32=.yandex.cloud.cic.v1.UpdateTrunkConnectionRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x1b\n\x13\x64\x65letion_protection\x18\x14 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x05\x10\x07J\x04\x08\x08\x10\rJ\x04\x08\x0e\x10\x11J\x04\x08\x13\x10\x14\"<\n\x1dUpdateTrunkConnectionMetadata\x12\x1b\n\x13trunk_connection_id\x18\x01 \x01(\t\"I\n\x1c\x44\x65leteTrunkConnectionRequest\x12)\n\x13trunk_connection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"<\n\x1d\x44\x65leteTrunkConnectionMetadata\x12\x1b\n\x13trunk_connection_id\x18\x01 \x01(\t\"x\n$ListTrunkConnectionOperationsRequest\x12)\n\x13trunk_connection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"w\n%ListTrunkConnectionOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xe8\x08\n\x16TrunkConnectionService\x12\x93\x01\n\x03Get\x12..yandex.cloud.cic.v1.GetTrunkConnectionRequest\x1a$.yandex.cloud.cic.v1.TrunkConnection\"6\x82\xd3\xe4\x93\x02\x30\x12./cic/v1/trunkConnections/{trunk_connection_id}\x12\x8d\x01\n\x04List\x12\x30.yandex.cloud.cic.v1.ListTrunkConnectionsRequest\x1a\x31.yandex.cloud.cic.v1.ListTrunkConnectionsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/cic/v1/trunkConnections\x12\xb7\x01\n\x06\x43reate\x12\x31.yandex.cloud.cic.v1.CreateTrunkConnectionRequest\x1a!.yandex.cloud.operation.Operation\"W\xb2\xd2*0\n\x1d\x43reateTrunkConnectionMetadata\x12\x0fTrunkConnection\x82\xd3\xe4\x93\x02\x1d\"\x18/cic/v1/trunkConnections:\x01*\x12\xcd\x01\n\x06Update\x12\x31.yandex.cloud.cic.v1.UpdateTrunkConnectionRequest\x1a!.yandex.cloud.operation.Operation\"m\xb2\xd2*0\n\x1dUpdateTrunkConnectionMetadata\x12\x0fTrunkConnection\x82\xd3\xe4\x93\x02\x33\x32./cic/v1/trunkConnections/{trunk_connection_id}:\x01*\x12\xd0\x01\n\x06\x44\x65lete\x12\x31.yandex.cloud.cic.v1.DeleteTrunkConnectionRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*6\n\x1d\x44\x65leteTrunkConnectionMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x30*./cic/v1/trunkConnections/{trunk_connection_id}\x12\xca\x01\n\x0eListOperations\x12\x39.yandex.cloud.cic.v1.ListTrunkConnectionOperationsRequest\x1a:.yandex.cloud.cic.v1.ListTrunkConnectionOperationsResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/cic/v1/trunkConnections/{trunk_connection_id}/operationsBV\n\x17yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cicb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cic.v1.trunk_connection_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cic'
  _globals['_GETTRUNKCONNECTIONREQUEST'].fields_by_name['trunk_connection_id']._loaded_options = None
  _globals['_GETTRUNKCONNECTIONREQUEST'].fields_by_name['trunk_connection_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTTRUNKCONNECTIONSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTTRUNKCONNECTIONSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTTRUNKCONNECTIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTTRUNKCONNECTIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTTRUNKCONNECTIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTTRUNKCONNECTIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTTRUNKCONNECTIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTTRUNKCONNECTIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATETRUNKCONNECTIONREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATETRUNKCONNECTIONREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATETRUNKCONNECTIONREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATETRUNKCONNECTIONREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATETRUNKCONNECTIONREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATETRUNKCONNECTIONREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATETRUNKCONNECTIONREQUEST'].fields_by_name['trunk_connection_id']._loaded_options = None
  _globals['_UPDATETRUNKCONNECTIONREQUEST'].fields_by_name['trunk_connection_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATETRUNKCONNECTIONREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATETRUNKCONNECTIONREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_DELETETRUNKCONNECTIONREQUEST'].fields_by_name['trunk_connection_id']._loaded_options = None
  _globals['_DELETETRUNKCONNECTIONREQUEST'].fields_by_name['trunk_connection_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTTRUNKCONNECTIONOPERATIONSREQUEST'].fields_by_name['trunk_connection_id']._loaded_options = None
  _globals['_LISTTRUNKCONNECTIONOPERATIONSREQUEST'].fields_by_name['trunk_connection_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0020\022./cic/v1/trunkConnections/{trunk_connection_id}'
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\032\022\030/cic/v1/trunkConnections'
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*0\n\035CreateTrunkConnectionMetadata\022\017TrunkConnection\202\323\344\223\002\035\"\030/cic/v1/trunkConnections:\001*'
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*0\n\035UpdateTrunkConnectionMetadata\022\017TrunkConnection\202\323\344\223\00232./cic/v1/trunkConnections/{trunk_connection_id}:\001*'
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*6\n\035DeleteTrunkConnectionMetadata\022\025google.protobuf.Empty\202\323\344\223\0020*./cic/v1/trunkConnections/{trunk_connection_id}'
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002;\0229/cic/v1/trunkConnections/{trunk_connection_id}/operations'
  _globals['_GETTRUNKCONNECTIONREQUEST']._serialized_start=429
  _globals['_GETTRUNKCONNECTIONREQUEST']._serialized_end=499
  _globals['_LISTTRUNKCONNECTIONSREQUEST']._serialized_start=502
  _globals['_LISTTRUNKCONNECTIONSREQUEST']._serialized_end=654
  _globals['_LISTTRUNKCONNECTIONSRESPONSE']._serialized_start=656
  _globals['_LISTTRUNKCONNECTIONSRESPONSE']._serialized_end=776
  _globals['_CREATETRUNKCONNECTIONREQUEST']._serialized_start=779
  _globals['_CREATETRUNKCONNECTIONREQUEST']._serialized_end=1915
  _globals['_CREATETRUNKCONNECTIONREQUEST_LABELSENTRY']._serialized_start=1476
  _globals['_CREATETRUNKCONNECTIONREQUEST_LABELSENTRY']._serialized_end=1521
  _globals['_CREATETRUNKCONNECTIONREQUEST_SINGLEPORTDIRECTJOINT']._serialized_start=1523
  _globals['_CREATETRUNKCONNECTIONREQUEST_SINGLEPORTDIRECTJOINT']._serialized_end=1623
  _globals['_CREATETRUNKCONNECTIONREQUEST_LAGDIRECTJOINT']._serialized_start=1626
  _globals['_CREATETRUNKCONNECTIONREQUEST_LAGDIRECTJOINT']._serialized_end=1810
  _globals['_CREATETRUNKCONNECTIONREQUEST_PARTNERJOINT']._serialized_start=1812
  _globals['_CREATETRUNKCONNECTIONREQUEST_PARTNERJOINT']._serialized_end=1882
  _globals['_CREATETRUNKCONNECTIONMETADATA']._serialized_start=1917
  _globals['_CREATETRUNKCONNECTIONMETADATA']._serialized_end=1977
  _globals['_UPDATETRUNKCONNECTIONREQUEST']._serialized_start=1980
  _globals['_UPDATETRUNKCONNECTIONREQUEST']._serialized_end=2522
  _globals['_UPDATETRUNKCONNECTIONREQUEST_LABELSENTRY']._serialized_start=1476
  _globals['_UPDATETRUNKCONNECTIONREQUEST_LABELSENTRY']._serialized_end=1521
  _globals['_UPDATETRUNKCONNECTIONMETADATA']._serialized_start=2524
  _globals['_UPDATETRUNKCONNECTIONMETADATA']._serialized_end=2584
  _globals['_DELETETRUNKCONNECTIONREQUEST']._serialized_start=2586
  _globals['_DELETETRUNKCONNECTIONREQUEST']._serialized_end=2659
  _globals['_DELETETRUNKCONNECTIONMETADATA']._serialized_start=2661
  _globals['_DELETETRUNKCONNECTIONMETADATA']._serialized_end=2721
  _globals['_LISTTRUNKCONNECTIONOPERATIONSREQUEST']._serialized_start=2723
  _globals['_LISTTRUNKCONNECTIONOPERATIONSREQUEST']._serialized_end=2843
  _globals['_LISTTRUNKCONNECTIONOPERATIONSRESPONSE']._serialized_start=2845
  _globals['_LISTTRUNKCONNECTIONOPERATIONSRESPONSE']._serialized_end=2964
  _globals['_TRUNKCONNECTIONSERVICE']._serialized_start=2967
  _globals['_TRUNKCONNECTIONSERVICE']._serialized_end=4095
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.cdn.v1 import shielding_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__pb2
from yandex.cloud.cdn.v1 import shielding_service_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/cdn/v1/shielding_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class ShieldingServiceStub(object):
    """Shielding management service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Activate = channel.unary_unary(
                '/yandex.cloud.cdn.v1.ShieldingService/Activate',
                request_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__service__pb2.ActivateShieldingRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Deactivate = channel.unary_unary(
                '/yandex.cloud.cdn.v1.ShieldingService/Deactivate',
                request_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__service__pb2.DeactivateShieldingRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Get = channel.unary_unary(
                '/yandex.cloud.cdn.v1.ShieldingService/Get',
                request_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__service__pb2.GetShieldingDetailsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__pb2.ShieldingDetails.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/yandex.cloud.cdn.v1.ShieldingService/Update',
                request_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__service__pb2.UpdateShieldingRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.ListAvailableLocations = channel.unary_unary(
                '/yandex.cloud.cdn.v1.ShieldingService/ListAvailableLocations',
                request_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__service__pb2.ListShieldingLocationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__service__pb2.ListShieldingLocationsResponse.FromString,
                _registered_method=True)


class ShieldingServiceServicer(object):
    """Shielding management service.
    """

    def Activate(self, request, context):
        """Activate shielding for a resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Deactivate(self, request, context):
        """Deactivate shielding for a resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Get shielding details by resource ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates shielding parameters for a resource, such as changing the geographical location of the shielding server.
        Changes may take up to 15 minutes to propagate across CDN servers.
        After updating, it is recommended to purge the resource's cache.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAvailableLocations(self, request, context):
        """Lists available geographical locations.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ShieldingServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Activate': grpc.unary_unary_rpc_method_handler(
                    servicer.Activate,
                    request_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__service__pb2.ActivateShieldingRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Deactivate': grpc.unary_unary_rpc_method_handler(
                    servicer.Deactivate,
                    request_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__service__pb2.DeactivateShieldingRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__service__pb2.GetShieldingDetailsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__pb2.ShieldingDetails.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__service__pb2.UpdateShieldingRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListAvailableLocations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAvailableLocations,
                    request_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__service__pb2.ListShieldingLocationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__service__pb2.ListShieldingLocationsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.cdn.v1.ShieldingService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.cdn.v1.ShieldingService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ShieldingService(object):
    """Shielding management service.
    """

    @staticmethod
    def Activate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cdn.v1.ShieldingService/Activate',
            yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__service__pb2.ActivateShieldingRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Deactivate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cdn.v1.ShieldingService/Deactivate',
            yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__service__pb2.DeactivateShieldingRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cdn.v1.ShieldingService/Get',
            yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__service__pb2.GetShieldingDetailsRequest.SerializeToString,
            yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__pb2.ShieldingDetails.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cdn.v1.ShieldingService/Update',
            yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__service__pb2.UpdateShieldingRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListAvailableLocations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cdn.v1.ShieldingService/ListAvailableLocations',
            yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__service__pb2.ListShieldingLocationsRequest.SerializeToString,
            yandex_dot_cloud_dot_cdn_dot_v1_dot_shielding__service__pb2.ListShieldingLocationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/tuning/v1/tuning_task.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/tuning/v1/tuning_task.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/ai/tuning/v1/tuning_task.proto\x12\x19yandex.cloud.ai.tuning.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xaf\x05\n\nTuningTask\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x14\n\x0coperation_id\x18\x03 \x01(\t\x12<\n\x06status\x18\x04 \x01(\x0e\x32,.yandex.cloud.ai.tuning.v1.TuningTask.Status\x12\x11\n\tfolder_id\x18\x05 \x01(\t\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x66inished_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10source_model_uri\x18\n \x01(\t\x12\x18\n\x10target_model_uri\x18\x0b \x01(\t\x12)\n\x04name\x18\x0c \x01(\tB\x1b\xf2\xc7\x31\x17^[A-Za-z0-9 _-]{3,100}$\x12\x13\n\x0b\x64\x65scription\x18\r \x01(\t\x12\x41\n\x06labels\x18\x0e \x03(\x0b\x32\x31.yandex.cloud.ai.tuning.v1.TuningTask.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x97\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0f\n\x0bIN_PROGRESS\x10\x03\x12\r\n\tCOMPLETED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x12\x0c\n\x08\x43\x41NCELED\x10\x06\x12\t\n\x05\x44RAFT\x10\x07\x12\x0c\n\x08\x41RCHIVED\x10\x08\x12\x08\n\x04PAID\x10\tJ\x04\x08\x02\x10\x03\x42\x63\n\x1dyandex.cloud.api.ai.tuning.v1ZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/tuning/v1;fomob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.tuning.v1.tuning_task_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035yandex.cloud.api.ai.tuning.v1ZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/tuning/v1;fomo'
  _globals['_TUNINGTASK_LABELSENTRY']._loaded_options = None
  _globals['_TUNINGTASK_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_TUNINGTASK'].fields_by_name['name']._loaded_options = None
  _globals['_TUNINGTASK'].fields_by_name['name']._serialized_options = b'\362\3071\027^[A-Za-z0-9 _-]{3,100}$'
  _globals['_TUNINGTASK']._serialized_start=139
  _globals['_TUNINGTASK']._serialized_end=826
  _globals['_TUNINGTASK_LABELSENTRY']._serialized_start=621
  _globals['_TUNINGTASK_LABELSENTRY']._serialized_end=666
  _globals['_TUNINGTASK_STATUS']._serialized_start=669
  _globals['_TUNINGTASK_STATUS']._serialized_end=820
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.clouddesktop.v1.disk_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DesktopGroup(google.protobuf.message.Message):
    """A desktop group resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DesktopGroup._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: DesktopGroup._Status.ValueType  # 0
        CREATING: DesktopGroup._Status.ValueType  # 1
        """Desktop group is being created."""
        ACTIVE: DesktopGroup._Status.ValueType  # 2
        """Desktop group is ready to use."""
        DELETING: DesktopGroup._Status.ValueType  # 3
        """Desktop group is being deleted."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: DesktopGroup.Status.ValueType  # 0
    CREATING: DesktopGroup.Status.ValueType  # 1
    """Desktop group is being created."""
    ACTIVE: DesktopGroup.Status.ValueType  # 2
    """Desktop group is ready to use."""
    DELETING: DesktopGroup.Status.ValueType  # 3
    """Desktop group is being deleted."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RESOURCES_SPEC_FIELD_NUMBER: builtins.int
    NETWORK_INTERFACE_SPEC_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    BOOT_DISK_SPEC_FIELD_NUMBER: builtins.int
    DATA_DISK_SPEC_FIELD_NUMBER: builtins.int
    GROUP_CONFIG_FIELD_NUMBER: builtins.int
    AUTO_UPDATE_POLICY_FIELD_NUMBER: builtins.int
    MANUAL_UPDATE_POLICY_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Desktop group ID."""
    folder_id: builtins.str
    """ID of the folder that the desktop group belongs to."""
    status: global___DesktopGroup.Status.ValueType
    """Status of the desktop group."""
    name: builtins.str
    """Name of the desktop group."""
    description: builtins.str
    """Description of the desktop group."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    @property
    def resources_spec(self) -> global___ResourcesSpec:
        """Resource specification of the desktop group."""

    @property
    def network_interface_spec(self) -> global___NetworkInterfaceSpec:
        """Network interface specification of the desktop group."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels of the desktop group."""

    @property
    def boot_disk_spec(self) -> yandex.cloud.clouddesktop.v1.disk_pb2.DiskSpec:
        """Boot disk specification of the desktop group."""

    @property
    def data_disk_spec(self) -> yandex.cloud.clouddesktop.v1.disk_pb2.DiskSpec:
        """Data disk specification of the desktop group."""

    @property
    def group_config(self) -> global___DesktopGroupConfiguration:
        """Desktop group configuration."""

    @property
    def auto_update_policy(self) -> global___AutoUpdatePolicy: ...
    @property
    def manual_update_policy(self) -> global___ManualUpdatePolicy: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        status: global___DesktopGroup.Status.ValueType = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        resources_spec: global___ResourcesSpec | None = ...,
        network_interface_spec: global___NetworkInterfaceSpec | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        boot_disk_spec: yandex.cloud.clouddesktop.v1.disk_pb2.DiskSpec | None = ...,
        data_disk_spec: yandex.cloud.clouddesktop.v1.disk_pb2.DiskSpec | None = ...,
        group_config: global___DesktopGroupConfiguration | None = ...,
        auto_update_policy: global___AutoUpdatePolicy | None = ...,
        manual_update_policy: global___ManualUpdatePolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["auto_update_policy", b"auto_update_policy", "boot_disk_spec", b"boot_disk_spec", "created_at", b"created_at", "data_disk_spec", b"data_disk_spec", "group_config", b"group_config", "manual_update_policy", b"manual_update_policy", "network_interface_spec", b"network_interface_spec", "resources_spec", b"resources_spec", "update_policy", b"update_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_update_policy", b"auto_update_policy", "boot_disk_spec", b"boot_disk_spec", "created_at", b"created_at", "data_disk_spec", b"data_disk_spec", "description", b"description", "folder_id", b"folder_id", "group_config", b"group_config", "id", b"id", "labels", b"labels", "manual_update_policy", b"manual_update_policy", "name", b"name", "network_interface_spec", b"network_interface_spec", "resources_spec", b"resources_spec", "status", b"status", "update_policy", b"update_policy"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["update_policy", b"update_policy"]) -> typing.Literal["auto_update_policy", "manual_update_policy"] | None: ...

global___DesktopGroup = DesktopGroup

@typing.final
class DesktopGroupConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _DesktopType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _DesktopTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DesktopGroupConfiguration._DesktopType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DESKTOP_TYPE_UNSPECIFIED: DesktopGroupConfiguration._DesktopType.ValueType  # 0
        PERSISTENT: DesktopGroupConfiguration._DesktopType.ValueType  # 1
        NON_PERSISTENT: DesktopGroupConfiguration._DesktopType.ValueType  # 2

    class DesktopType(_DesktopType, metaclass=_DesktopTypeEnumTypeWrapper): ...
    DESKTOP_TYPE_UNSPECIFIED: DesktopGroupConfiguration.DesktopType.ValueType  # 0
    PERSISTENT: DesktopGroupConfiguration.DesktopType.ValueType  # 1
    NON_PERSISTENT: DesktopGroupConfiguration.DesktopType.ValueType  # 2

    MIN_READY_DESKTOPS_FIELD_NUMBER: builtins.int
    MAX_DESKTOPS_AMOUNT_FIELD_NUMBER: builtins.int
    DESKTOP_TYPE_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    min_ready_desktops: builtins.int
    """Minimum number of ready desktops."""
    max_desktops_amount: builtins.int
    """Maximum number of desktops."""
    desktop_type: global___DesktopGroupConfiguration.DesktopType.ValueType
    """Type of the desktop."""
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.access.access_pb2.Subject]:
        """List of members of the desktop group."""

    def __init__(
        self,
        *,
        min_ready_desktops: builtins.int = ...,
        max_desktops_amount: builtins.int = ...,
        desktop_type: global___DesktopGroupConfiguration.DesktopType.ValueType = ...,
        members: collections.abc.Iterable[yandex.cloud.access.access_pb2.Subject] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_type", b"desktop_type", "max_desktops_amount", b"max_desktops_amount", "members", b"members", "min_ready_desktops", b"min_ready_desktops"]) -> None: ...

global___DesktopGroupConfiguration = DesktopGroupConfiguration

@typing.final
class ResourcesSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEMORY_FIELD_NUMBER: builtins.int
    CORES_FIELD_NUMBER: builtins.int
    CORE_FRACTION_FIELD_NUMBER: builtins.int
    memory: builtins.int
    """RAM volume, in bytes."""
    cores: builtins.int
    """Number of CPU cores."""
    core_fraction: builtins.int
    """Baseline level of CPU performance with the ability to burst performance above that baseline level.
    This field sets baseline performance for each core.
    """
    def __init__(
        self,
        *,
        memory: builtins.int = ...,
        cores: builtins.int = ...,
        core_fraction: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["core_fraction", b"core_fraction", "cores", b"cores", "memory", b"memory"]) -> None: ...

global___ResourcesSpec = ResourcesSpec

@typing.final
class NetworkInterfaceSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_ID_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    network_id: builtins.str
    """ID of the network interface specification."""
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of subnet IDs."""

    def __init__(
        self,
        *,
        network_id: builtins.str = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_id", b"network_id", "subnet_ids", b"subnet_ids"]) -> None: ...

global___NetworkInterfaceSpec = NetworkInterfaceSpec

@typing.final
class ManualUpdatePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ManualUpdatePolicy = ManualUpdatePolicy

@typing.final
class AutoUpdatePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AutoUpdatePolicy = AutoUpdatePolicy
